<?php

namespace CRM\Controller;

use CRM\Traits\TResponse;
use CRM\Service\TaskScheduleService;
use Zeedhi\Framework\DTO\Request;

class TaskScheduleController
{
    protected $TaskScheduleService;

    use TResponse;

    public function __construct(TaskScheduleService $TaskScheduleService)
    {
        $this->TaskScheduleService = $TaskScheduleService;
    }

    /**
     * Retrieves task schedule based on lead data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getTaskScheduleBasedOnLead(Request $request): array
    {
        try {
            $data = $this->TaskScheduleService->getTaskScheduleBasedOnLead($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    /**
     * Retrieves task classification data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getTaskClassification(Request $request): array
    {
        try {
            $data = $this->TaskScheduleService->getTaskClassification($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    public function checkIfThereAreAnyOpenTasks(Request $request): array
    {
        try {
            $data = $this->TaskScheduleService->checkIfThereAreAnyOpenTasks($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    public function insertLeadEvolNextTask(Request $request): array
    {
        try {
            $data = $this->TaskScheduleService->insertLeadEvolNextTask($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }
}
