<?php

namespace CRM\Factory;

use CRM\Traits\TQuery;
use Doctrine\ORM\EntityManager;

class CrmConcorrenteFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCompetitionFactory()
    {
        $sql = "SELECT
        CONC.*,
        ESTADO.NMESTADO,
        PAIS.NMPAIS,
        MUNICIPIO.NMMUNICIPIO,
        BAIRRO.NMBAIRRO
        FROM
            CRM_CONCORRENTE CONC
            LEFT JOIN PAIS ON PAIS.CDPAIS = CONC.CDPAIS
                            AND PAIS.NRORG = CONC.NRORG
            LEFT JOIN ESTADO ON ESTADO.SGESTADO = CONC.SGESTADO
                                AND ESTADO.NRORG = CONC.NRORG
                                AND ESTADO.CDPAIS = PAIS.CDPAIS
            LEFT JOIN MUNICIPIO ON MUNICIPIO.CDMUNICIPIO = CONC.CDMUNICIPIO
                                AND MUNICIPIO.NRORG = CONC.NRORG
                                AND MUNICIPIO.CDPAIS = PAIS.CDPAIS
                                AND MUNICIPIO.SGESTADO = ESTADO.SGESTADO
            LEFT JOIN BAIRRO ON BAIRRO.CDBAIRRO = CONC.CDBAIRRO
                                AND BAIRRO.NRORG = CONC.NRORG
                                AND BAIRRO.CDPAIS = PAIS.CDPAIS
                                AND BAIRRO.SGESTADO = ESTADO.SGESTADO
                                AND BAIRRO.CDMUNICIPIO = MUNICIPIO.CDMUNICIPIO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertNewCompetitionFactory($params)
    {
        $sql = "INSERT INTO CRM_CONCORRENTE (
            NRCONCORRENTE,    NRINSCRICAOCONC,  CDTIPOINSCRICAO,  NMRAZSOCCONC,    NMFANTCONN,
            NRCEPCONC,        CDPAIS,           SGESTADO,         CDMUNICIPIO,     CDBAIRRO,
            DSENDERECOCONC,   NRENDERECOCONC,   DSCOMPLEENDECONC, NRTELCONC,       DSEMAILCONC,
            DSHOMEPAGECONC,   DSOBSERVCONC,     NRORG,            DTINCLUSAO,      DTULTATU,
            NRORGINCLUSAO,    NRORGULTATU,      CDOPERINCLUSAO,   CDOPERULTATU,    IDATIVO
        ) VALUES (
            :NRCONCORRENTE,   :NRINSCRICAOCONC, :CDTIPOINSCRICAO,  :NMRAZSOCCONC,   :NMFANTCONN,
            :NRCEPCONC,       :CDPAIS,          :SGESTADO,         :CDMUNICIPIO,    :CDBAIRRO,
            :DSENDERECOCONC,  :NRENDERECOCONC,  :DSCOMPLEENDECONC, :NRTELCONC,      :DSEMAILCONC,
            :DSHOMEPAGECONC,  :DSOBSERVCONC,    :NRORG,            SYSDATE,         SYSDATE,
            :NRORGINCLUSAO,   :NRORGULTATU,     :CDOPERINCLUSAO,   :CDOPERULTATU,   :IDATIVO
        )";

        $this->connection->executeStatement($sql, $params);
    }

    
    public function updateCompetitionFactory($params)
    {
        $sql = "UPDATE CRM_CONCORRENTE
        SET
            NRINSCRICAOCONC = :NRINSCRICAOCONC,
            CDTIPOINSCRICAO = :CDTIPOINSCRICAO,
            NMRAZSOCCONC = :NMRAZSOCCONC,
            NMFANTCONN = :NMFANTCONN,
            NRCEPCONC = :NRCEPCONC,
            CDPAIS = :CDPAIS,
            SGESTADO = :SGESTADO,
            CDMUNICIPIO = :CDMUNICIPIO,
            CDBAIRRO = :CDBAIRRO,
            DSENDERECOCONC = :DSENDERECOCONC,
            NRENDERECOCONC = :NRENDERECOCONC,
            DSCOMPLEENDECONC = :DSCOMPLEENDECONC,
            NRTELCONC = :NRTELCONC,
            DSEMAILCONC = :DSEMAILCONC,
            DSHOMEPAGECONC = :DSHOMEPAGECONC,
            DSOBSERVCONC = :DSOBSERVCONC,
            NRORG = :NRORG,
            DTULTATU = SYSDATE,
            DTINCLUSAO = SYSDATE,
            NRORGINCLUSAO = :NRORGINCLUSAO,
            CDOPERINCLUSAO = :CDOPERINCLUSAO,
            NRORGULTATU = :NRORGULTATU,
            CDOPERULTATU = :CDOPERULTATU,
            IDATIVO = :IDATIVO
        WHERE NRCONCORRENTE = :NRCONCORRENTE";

        $this->connection->executeStatement($sql, $params);
    }

    public function deleteCompetitionFactory($params)
    {
        $sql = "DELETE
                FROM CRM_CONCORRENTE
                WHERE NRCONCORRENTE IN (" . $params . ")";

        $this->connection->executeStatement($sql);
    }

    public function findRelationshipFactory($params)
    {

        $sql = "SELECT COUNT (NRCONCORRENTE) AS NRCONCORRENTE  FROM CRM_CONCORRPROSPECT 
                WHERE NRCONCORRENTE = :NRCONCORRENTE";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
}
