<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class CrmMetasFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCrmMetasFactory()
    {
        $sql = "SELECT * FROM CRM_METAS ORDER BY NMMETA ASC";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
    
    public function saveEditMeta( $params )
    {
        $sql = "UPDATE CRM_METAS
        SET NMMETA          = :NMMETA,
            CDTIPOMETA      = :CDTIPOMETA,
            VRMINMETA       = :VRMINMETA,
            DTULTATU        = SYSDATE,
            NRORGULTATU     = :NRORGULTATU,
            CDOPERULTATU    = :CDOPERULTATU,
            IDATIVO         = :IDATIVO
        WHERE NRMETAS       = :NRMETAS";

        $this->connection->executeStatement($sql, $params);
    }

    public function insertNewMeta( $params )
    {
        $sql = "INSERT INTO CRM_METAS
                       (NRMETAS,
                        NMMETA,
                        CDTIPOMETA,
                        VRMINMETA,  
                        NRORG,
                        NRORGINCLUSAO,  
                        CDOPERINCLUSAO,
                        NRORGULTATU,  
                        CDOPERULTATU,    
                        IDATIVO,
                        DTINCLUSAO)        
                VALUES (:NRMETAS,
                        :NMMETA,
                        :CDTIPOMETA,
                        :VRMINMETA,  
                        :NRORG,
                        :NRORGINCLUSAO,  
                        :CDOPERINCLUSAO,
                        :NRORGULTATU,  
                        :CDOPERULTATU,    
                        :IDATIVO, 
                        SYSDATE)";
        $this->connection->executeStatement($sql, $params);
       
    }

   
    public function insertOperadorMeta($params)
    {
        $sql = "INSERT INTO CRM_OPERMETA
                    (NROPERMETA,
                        NRORG,
                        NRMETAS,
                        CDOPERADOR,
                        CDOPERINCLUSAO,
                        NRORGINCLUSAO,
                        DTINCLUSAO)
                VALUES (
                        :NROPERMETA,
                        :NRORG,
                        :NRMETAS,
                        :CDOPERADOR,
                        :CDOPERINCLUSAO,
                        :NRORG,
                        SYSDATE)";
        $this->connection->executeStatement($sql, $params);
    }

    public function getOperadoresMeta($params)
    {
        $sql = "SELECT
                    CRM_OPERMETA.*,
                    OPER.NMOPERADOR
                FROM
                    CRM_OPERMETA
                    LEFT JOIN OPERADOR OPER ON OPER.CDOPERADOR = CRM_OPERMETA.CDOPERADOR
                                   AND OPER.NRORG = CRM_OPERMETA.NRORG  
                                   WHERE CRM_OPERMETA.NRMETAS = :NRMETAS";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }
    public function getOperadorMeta($params)
    {
        $sql = "SELECT
        CDOPERADOR,
        NMOPERADOR,
        NRORG
    FROM
        OPERADOR
    WHERE
        CDOPERADOR NOT IN (
            SELECT
                CDOPERADOR
            FROM
                CRM_OPERMETA
                LEFT JOIN CRM_METAS ON CRM_METAS.NRMETAS = CRM_OPERMETA.NRMETAS
                                       AND CRM_METAS.NRORG = CRM_OPERMETA.NRORG
            WHERE
                CRM_METAS.CDTIPOMETA = :CDTIPOMETA
        )
        AND ( ( :IDTPOPERADOR = 'R'
                AND OPERADOR.CDOPERADOR IN (
            SELECT
                CDOPERADOR
            FROM
                CRM_OPERREVENDA
            WHERE
                NRREVENDA = :NRREVENDA
        ) )
              OR :IDTPOPERADOR <> 'R' )";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);

    }

    public function deleteCrmMetaOperador($params)
    {  
        $sql = "DELETE FROM CRM_OPERMETA
                WHERE NROPERMETA            = :NROPERMETA
                    AND NRORG               = :NRORG
                    AND NRMETAS             = :NRMETAS";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    public function deleteCrmMetaRegistro($params)
    {  
        $sql = "DELETE FROM CRM_METAS
                WHERE NRMETAS             = :NRMETAS  
                    AND NRORG             = :NRORG";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
}

