<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManagerInterface;
use CRM\Traits\TQuery;
use Doctrine\DBAL\Connection;

class LeadFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManagerInterface  $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function verifyExistentPartnership($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select('*')
                ->from('PARCERIA')
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->eq('CDTIPOPARCEIRO', ':CDTIPOPARCEIRO'))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'));

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO']);
            $queryBuilder->setParameter('CDTIPOPARCEIRO', $paramsQuery['CDTIPOPARCEIRO']);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());

            if (empty($result)) {
                return true;
            } else {
                return false;
            }
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function getOperatorInformation($paramsQuery): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'CDOPERADOR',
                    'NMOPERADOR',
                    'NRPARCNEGOCIO'
                ])
                ->from('OPERADOR')
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'))
                ->orderBy('NMOPERADOR', 'ASC');

            $queryBuilder->setParameter('NRORG', $paramsQuery['NRORG']);
            $queryBuilder->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO']);
            $result = $queryBuilder->execute()->fetchAllAssociative();

            if (!empty($result)) {
                return array('NRPARCNEGOCIO' => $result[0]['NRPARCNEGOCIO'], 'CDOPERADOR' => $result[0]['CDOPERADOR']);
            } else {
                return array();
            }
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function findSimilarName($nmprincipalparc, $nmsecundariparc, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select('*')
                ->from('CRM_STATUSPARC')
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', '(SELECT MAX(NRPARCNEGOCIO) FROM PARCNEGOCIO WHERE UPPER(NMPRINCIPALPARC) = UPPER(:NMPRINCIPALPARC) AND UPPER(NMSECUNDARIPARC) = UPPER(:NMSECUNDARIPARC) AND NRORG = :NRORG)'))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'));

            $queryBuilder->setParameter('NRORG', $nrorg);
            $queryBuilder->setParameter('NMPRINCIPALPARC', $nmprincipalparc);
            $queryBuilder->setParameter('NMSECUNDARIPARC', $nmsecundariparc);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function findParcByRegistration($NRORG, $INSCRICAO, $IDTPIJURCAN)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $subQuery = '';

            if ($IDTPIJURCAN === 'J') {
                $subQuery = "(SELECT MAX(NRPARCNEGOCIO) FROM PARCNEGOCIO WHERE NRINSCRICAOPARC LIKE ('%' || :INSCRICAO || '%') AND NRORG = :NRORG)";
            } else {
                $subQuery = "(SELECT MAX(NRPARCNEGOCIO) FROM PARCNEGOCIO WHERE NRINSCRICAOPARC = :INSCRICAO AND NRORG = :NRORG)";
            }

            $queryBuilder
                ->select('*')
                ->from('CRM_STATUSPARC')
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', $subQuery))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'));

            $queryBuilder->setParameter('NRORG', $NRORG);
            $queryBuilder->setParameter('INSCRICAO', $INSCRICAO);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());

            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getResponsibleOperator($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    "OP.CDOPERADOR",
                    "OP.NMOPERADOR",
                    "OP.NRPARCNEGOCIO AS NRPARCRESP",
                    "OP.NRPARCNEGOCIO",
                    "OP.DSEMAILOPER",
                    "OP.IDOPERATIVO",
                    "OP.CDFUNC",
                    "OP.NRORG",
                    "ORG.CRM_NRORGTRAB",
                    "OP.IDATIVO",
                    "OP.IDTPOPERADOR"
                ])
                ->from('OPERADOR', 'OP')
                ->leftJoin('OP', 'CRM_ORGREL', 'ORG', 'ORG.NRORG = OP.NRORG AND ORG.CDOPERADOR = OP.CDOPERADOR')
                ->where($queryBuilder->expr()->eq('OP.IDOPERATIVO', ':idoperativo'))
                ->setParameter('idoperativo', $params["IDOPERATIVO"])
                ->orderBy('OP.NMOPERADOR', 'ASC');

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function getMarketSegment($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    "DSSEGMER",
                    "DTULTATUSEGM",
                    "CDPRECOPROP",
                    "NRORG",
                    "DTINCLUSAO",
                    "DTULTATU",
                    "NRORGINCLUSAO",
                    "CDOPERINCLUSAO",
                    "NRORGULTATU",
                    "CDOPERULTATU",
                    "IDATIVO",
                    "CDSEGMER"
                ])
                ->from('SEGMERCADO')
                ->orderBy('DSSEGMER', 'ASC');

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function getLeads($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                "CRM_CANDIDATO.NRSEQPERFILRESPONSAVEL",
                "CRM_CANDIDATO.NRCANDIDATO",
                "CRM_CANDIDATO.IDPARCFUNDIDO",
                "CRM_CANDIDATO.NMCANDIDATO",
                "CRM_CANDIDATO.IDTPIJURCAN",
                "CRM_CANDIDATO.NRINSJURCAN",
                "CRM_CANDIDATO.CDSEGMER",
                "CRM_CANDIDATO.DESCTITULOCAN",
                "CRM_CANDIDATO.NMFANTCAN",
                "CRM_CANDIDATO.DSEMAILCAN",
                "CRM_CANDIDATO.DSTELEFONECAN",
                "CRM_CANDIDATO.NRFUNCCAN",
                "CRM_CANDIDATO.CDMODODIVULG",
                "CRM_CANDIDATO.NRPARCNEGOCIO AS NRPARCNEGOCIO",
                "CRM_CANDIDATO.NRCONTATO AS NRCONTATO",
                "CRM_CANDIDATO.NRORG AS NRORG",
                "TRUNC(CRM_CANDIDATO.DTINCLUSAO) AS INCLUSAO",
                "CRM_CANDIDATO.CDOPERINCLUSAO AS CDOPERINCLUSAO",
                "CRM_CANDIDATO.NRORGINCLUSAO",
                "CRM_CANDIDATO.DTULTATU",
                "CRM_CANDIDATO.NRORGULTATU",
                "CRM_CANDIDATO.CDOPERULTATU",
                "CRM_CANDIDATO.CDFILIAL AS CDFILIAL",
                "CRM_CANDIDATO.NRSEQCONTATO AS NRSEQCONTATO",
                "CRM_CANDIDATO.DSOBSERVACAOLEAD AS DSOBSERVACAOLEAD",
                "CRM_CANDIDATO.NRPARCPROPRI",
                "SEG.DSSEGMER",
                "PAIS.NMPAIS",
                "PAIS.CDPAIS",
                "ESTADO.SGESTADO",
                "ESTADO.NMESTADO",
                "BAIRRO.CDBAIRRO",
                "BAIRRO.NMBAIRRO",
                "ENDERECO.DSENDERECO",
                "ENDERECO.NRCEPENDERECO",
                "ENDERECO.DSCOMPLEENDERECO",
                "ENDERECO.NRIMOVELENDERECO",
                "MUNICIPIO.CDMUNICIPIO",
                "MUNICIPIO.NMMUNICIPIO",
                "PARCLEAD.DTNASCIFUNDPARC",
                "PARCLEAD.NMPRINCIPALPARC",
                "OPERRES.CDOPERADOR",
                "OPERRES.IDOPERATIVO",
                "OPERRES.NMOPERADOR",
                "OPERRES.NMOPERADOR AS NMOPERULTATU",
                "GER_PARCNEGOCIOINFO.NRMODORECEBINFO",
                "MODO.NMMODORECEBINFO",
                "MODODIVULG.NMMODODIVULG",
                "MODODIVULG.IDRDSTATION",
                "STAT.IDATIVO",
                "CASE WHEN STAT.IDSTATUS IS NULL THEN '2' ELSE STAT.IDSTATUS END AS IDSTATUSCAN",
            ])
                ->from('CRM_CANDIDATO', "CRM_CANDIDATO")
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'CRM_STATUSPARC',
                    'STAT',
                    'CRM_CANDIDATO.NRPARCNEGOCIO = STAT.NRPARCNEGOCIO
                        AND STAT.CRM_NRORGTRAB = :CRM_NRORGTRAB 
                        AND CRM_CANDIDATO.NRORG = STAT.NRORG
                        AND STAT.STATUSPARC = :STATUSPARC'
                )
                ->leftJoin(
                    'STAT',
                    'OPERADOR',
                    'OPERRES',
                    'STAT.CDOPERRESP = OPERRES.CDOPERADOR 
                        AND CRM_CANDIDATO.NRPARCPROPRI = OPERRES.NRPARCNEGOCIO
                        AND OPERRES.NRORG = CRM_CANDIDATO.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'PARCNEGOCIO',
                    'PARCLEAD',
                    'CRM_CANDIDATO.NRPARCNEGOCIO = PARCLEAD.NRPARCNEGOCIO 
                        AND STAT.CDOPERRESP = PARCLEAD.CDOPERRESPONSAVEL
                        AND CRM_CANDIDATO.NRORG = PARCLEAD.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'GER_PARCNEGOCIOINFO',
                    'GER_PARCNEGOCIOINFO',
                    'CRM_CANDIDATO.NRPARCNEGOCIO = GER_PARCNEGOCIOINFO.NRPARCNEGOCIO 
                        AND CRM_CANDIDATO.NRORG = GER_PARCNEGOCIOINFO.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'CRM_MODORECEBINFO',
                    'MODO',
                    'GER_PARCNEGOCIOINFO.NRMODORECEBINFO = MODO.NRMODORECEBINFO
                        AND CRM_CANDIDATO.NRORG = GER_PARCNEGOCIOINFO.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'CRM_PERFILATIV',
                    'PERFIL',
                    'PERFIL.NRSEQPERFATIV = CRM_CANDIDATO.NRSEQPERFILRESPONSAVEL
                    AND PERFIL.NRORG = CRM_CANDIDATO.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'SEGMERCADO',
                    'SEG',
                    'SEG.CDSEGMER = CRM_CANDIDATO.CDSEGMER 
                        AND SEG.NRORG = CRM_CANDIDATO.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'MODODIVULG',
                    'MODODIVULG',
                    'CRM_CANDIDATO.CDMODODIVULG = MODODIVULG.CDMODODIVULG
                        AND CRM_CANDIDATO.NRORG = MODODIVULG.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'ENDERECOPARC',
                    'ENDERECO',
                    'ENDERECO.NRORG = CRM_CANDIDATO.NRORG
                        AND CRM_CANDIDATO.NRPARCNEGOCIO = ENDERECO.NRPARCNEGOCIO'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'PAIS',
                    'PAIS',
                    'PAIS.CDPAIS = ENDERECO.CDPAIS
                   AND PAIS.NRORG = CRM_CANDIDATO.NRORG'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'ESTADO',
                    'ESTADO',
                    'ESTADO.SGESTADO = ENDERECO.SGESTADO
                   AND ESTADO.CDPAIS = ENDERECO.CDPAIS
                   AND (ESTADO.NRORG = ENDERECO.NRORG OR ESTADO.NRORG = :NRORG)'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'MUNICIPIO',
                    'MUNICIPIO',
                    'MUNICIPIO.CDPAIS = CRM_CANDIDATO.CDPAIS
                   AND MUNICIPIO.SGESTADO = CRM_CANDIDATO.SGESTADO
                   AND MUNICIPIO.CDMUNICIPIO = CRM_CANDIDATO.CDMUNICIPIO
                   AND (MUNICIPIO.NRORG = CRM_CANDIDATO.NRORG OR MUNICIPIO.NRORG = :NRORG)'
                )
                ->leftJoin(
                    'CRM_CANDIDATO',
                    'BAIRRO',
                    'BAIRRO',
                    'BAIRRO.CDPAIS = CRM_CANDIDATO.CDPAIS
                    AND BAIRRO.SGESTADO = CRM_CANDIDATO.SGESTADO
                    AND BAIRRO.CDMUNICIPIO = CRM_CANDIDATO.CDMUNICIPIO
                    AND BAIRRO.CDBAIRRO = CRM_CANDIDATO.CDBAIRRO
                    AND (BAIRRO.NRORG = CRM_CANDIDATO.NRORG OR BAIRRO.NRORG = :NRORG)'
                );
            $queryBuilder->setParameter('NRORG', $params["NRORG"]);
            $queryBuilder->setParameter('IDATIVO', $params["IDATIVO"]);
            $queryBuilder->setParameter('STATUSPARC', $params["STATUSPARC"]);
            $queryBuilder->setParameter('CRM_NRORGTRAB', $params["CRM_NRORGTRAB"]);
            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function saveNewLeads($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function findCandidate($nrparcnegocio, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                '*'
            ])
                ->from('CRM_CANDIDATO')
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'))
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'));

            $queryBuilder->setParameter('NRORG', $nrorg);
            $queryBuilder->setParameter('NRPARCNEGOCIO', $nrparcnegocio);
            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function findProspect($nrparcnegocio, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                '*'
            ])
                ->from('PROSPECT')
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'))
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'));

            $queryBuilder->setParameter('NRORG', $nrorg);
            $queryBuilder->setParameter('NRPARCNEGOCIO', $nrparcnegocio);
            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function findClient($nrparcnegocio, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                '*'
            ])
                ->from('CLIENTE')
                ->where($queryBuilder->expr()->eq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'));

            $queryBuilder->setParameter('NRORG', $nrorg);
            $queryBuilder->setParameter('NRPARCNEGOCIO', $nrparcnegocio);
            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function findExclusiveParc($nrparcnegocio, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                '*'
            ])
                ->from('CRM_STATUSPARC')
                ->where($queryBuilder->expr()->neq('CRM_NRORGTRAB', ':CRM_NRORGTRAB'))
                ->andWhere($queryBuilder->expr()->neq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->neq('NRORG', ':NRORG'));

            $queryBuilder->setParameter('CRM_NRORGTRAB', $nrorg);
            $queryBuilder->setParameter('NRPARCNEGOCIO', $nrparcnegocio);
            $queryBuilder->setParameter('NRORG', $nrorg);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function returnParcAddress($nrparcnegocio, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                'ENDERECOPARC.*',
                'PAIS.NMPAIS',
                'ESTADO.NMESTADO',
                'MUNICIPIO.NMMUNICIPIO',
                'BAIRRO.NMBAIRRO'
            ])
                ->from('ENDERECOPARC', 'ENDERECOPARC')
                ->leftJoin('ENDERECOPARC', 'PAIS', 'PAIS', 'ENDERECOPARC.CDPAIS = PAIS.CDPAIS AND ENDERECOPARC.NRORG = PAIS.NRORG')
                ->leftJoin('ENDERECOPARC', 'ESTADO', 'ESTADO', 'ENDERECOPARC.CDPAIS = ESTADO.CDPAIS AND ENDERECOPARC.SGESTADO = ESTADO.SGESTADO AND ENDERECOPARC.NRORG = ESTADO.NRORG')
                ->leftJoin('ENDERECOPARC', 'MUNICIPIO', 'MUNICIPIO', 'ENDERECOPARC.CDPAIS = MUNICIPIO.CDPAIS AND ENDERECOPARC.SGESTADO = MUNICIPIO.SGESTADO AND ENDERECOPARC.CDMUNICIPIO = MUNICIPIO.CDMUNICIPIO AND ENDERECOPARC.NRORG = MUNICIPIO.NRORG')
                ->leftJoin('ENDERECOPARC', 'BAIRRO', 'BAIRRO', 'ENDERECOPARC.CDPAIS = BAIRRO.CDPAIS AND ENDERECOPARC.SGESTADO = BAIRRO.SGESTADO AND ENDERECOPARC.CDMUNICIPIO = BAIRRO.CDMUNICIPIO AND ENDERECOPARC.CDBAIRRO = BAIRRO.CDBAIRRO AND ENDERECOPARC.NRORG = BAIRRO.NRORG')
                ->where($queryBuilder->expr()->eq('ENDERECOPARC.NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->eq('ENDERECOPARC.NRORG', ':NRORG'))
                ->andWhere($queryBuilder->expr()->eq('ENDERECOPARC.CDTIPOENDERECO', ':CDTIPOENDERECO'))
                ->setMaxResults(1);

            $queryBuilder->setParameter('NRPARCNEGOCIO', $nrparcnegocio);
            $queryBuilder->setParameter('CDTIPOENDERECO', 'PRINCIPAL');
            $queryBuilder->setParameter('NRORG', $nrorg);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function findEmailAndTel($nrparcnegocio, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                'CDCOMUNICAPARC'
            ])
                ->from('COMUNICAPARC')
                ->where($queryBuilder->expr()->eq('CDFORMACOMU', '05'))
                ->andWhere($queryBuilder->expr()->eq('NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'))
                ->setMaxResults(1);

            $queryBuilder->setParameter('NRPARCNEGOCIO', $nrparcnegocio);
            $queryBuilder->setParameter('NRORG', $nrorg);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function searchSegMerc($cdSegMer, $nrorg)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->select([
                '*'
            ])
                ->from('SEGMERCADO')
                ->where($queryBuilder->expr()->eq('CDSEGMER', ':CDSEGMER'))
                ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'));

            $queryBuilder->setParameter('CDSEGMER', $cdSegMer);
            $queryBuilder->setParameter('NRORG', $nrorg);

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            if (empty($result)) {
                return false;
            } else {
                return $result[0];
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function verifyLeadCNPJ($paramsVerifyLeadCPNJ)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'PARC.NMPRINCIPALPARC',
                    'STAT.STATUSPARC AS TIPOPARC'
                ])
                ->from('PARCNEGOCIO', 'PARC')
                ->leftJoin('PARC', 'CRM_STATUSPARC', 'STAT', 'STAT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO AND STAT.NRORG = PARC.NRORG AND STAT.CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->where($queryBuilder->expr()->like('PARC.NRINSCRICAOPARC', ':INSCRICAO'))
                ->andWhere(
                    $queryBuilder->expr()->or(
                        $queryBuilder->expr()->neq('PARC.NRPARCNEGOCIO', ':PKVALUE'),
                        $queryBuilder->expr()->isNull(':PKVALUE')
                    )
                )
                ->andWhere($queryBuilder->expr()->eq('PARC.NRORG', ':NRORG'));

            $queryBuilder->setParameter('CRM_NRORGTRAB', $paramsVerifyLeadCPNJ['CRM_NRORGTRAB']);
            $queryBuilder->setParameter('INSCRICAO', $paramsVerifyLeadCPNJ['INSCRICAO']);
            $queryBuilder->setParameter('PKVALUE', $paramsVerifyLeadCPNJ['PKVALUE']);
            $queryBuilder->setParameter('NRORG', $paramsVerifyLeadCPNJ['NRORG']);

            $leads = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $leads;
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function verifyLeadExactCNPJ($paramsVerifyLeadCPNJ)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'PARC.NMPRINCIPALPARC',
                    'STAT.STATUSPARC AS TIPOPARC'
                ])
                ->from('PARCNEGOCIO', 'PARC')
                ->leftJoin('PARC', 'CRM_STATUSPARC', 'STAT', 'STAT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO AND STAT.NRORG = PARC.NRORG AND STAT.CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->where($queryBuilder->expr()->eq('PARC.NRINSCRICAOPARC', ':INSCRICAO'))
                ->andWhere(
                    $queryBuilder->expr()->or(
                        $queryBuilder->expr()->neq('PARC.NRPARCNEGOCIO', ':PKVALUE'),
                        $queryBuilder->expr()->isNull(':PKVALUE')
                    )
                )
                ->andWhere($queryBuilder->expr()->eq('PARC.NRORG', ':NRORG'));

            $queryBuilder->setParameter('CRM_NRORGTRAB', $paramsVerifyLeadCPNJ['CRM_NRORGTRAB']);
            $queryBuilder->setParameter('INSCRICAO', $paramsVerifyLeadCPNJ['INSCRICAO']);
            $queryBuilder->setParameter('PKVALUE', $paramsVerifyLeadCPNJ['PKVALUE']);
            $queryBuilder->setParameter('NRORG', $paramsVerifyLeadCPNJ['NRORG']);

            $leads = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $leads;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function verifyLeadName($paramsVerifyLeadName): array
    {
        if (!empty($paramsVerifyLeadName['NMCANDIDATO'])) {
            try {
                $queryBuilder = $this->connection->createQueryBuilder();
                $queryBuilder
                    ->select([
                        'PARC.NMPRINCIPALPARC',
                        'PARC.NMSECUNDARIPARC',
                        'STAT.STATUSPARC AS TIPOPARC'
                    ])
                    ->from('PARCNEGOCIO', 'PARC')
                    ->leftJoin('PARC', 'CRM_STATUSPARC', 'STAT', 'STAT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO AND STAT.NRORG = PARC.NRORG AND STAT.CRM_NRORGTRAB = :CRM_NRORGTRAB')
                    ->where($queryBuilder->expr()->like('UPPER(PARC.NMPRINCIPALPARC)', 'UPPER(:NMCANDIDATO)'))
                    ->andWhere(
                        $queryBuilder->expr()->or(
                            $queryBuilder->expr()->neq('PARC.NRPARCNEGOCIO', ':PKVALUE'),
                            $queryBuilder->expr()->isNull(':PKVALUE')
                        )
                    )
                    ->andWhere($queryBuilder->expr()->eq('PARC.NRORG', ':NRORG'));

                $queryBuilder->setParameter('CRM_NRORGTRAB', $paramsVerifyLeadName['CRM_NRORGTRAB']);
                $queryBuilder->setParameter('NMCANDIDATO', $paramsVerifyLeadName['NMCANDIDATO']);
                $queryBuilder->setParameter('PKVALUE', $paramsVerifyLeadName['PKVALUE']);
                $queryBuilder->setParameter('NRORG', $paramsVerifyLeadName['NRORG']);

                $leads = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
                return $leads;
            } catch (\Exception $e) {
                throw $e;
            }
        } else {
            return array();
        }
    }

    public function verifyLeadInsc($paramsVerifyLeadCPNJ)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'PARC.NMPRINCIPALPARC',
                    'PARC.CDTIPOPARCPRINCIPAL AS TIPOPARC'
                ])
                ->from('PARCNEGOCIO', 'PARC')
                ->leftJoin('PARC', 'CRM_STATUSPARC', 'STAT', 'STAT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO AND STAT.NRORG = PARC.NRORG AND STAT.CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->where($queryBuilder->expr()->eq('PARC.NRINSCRICAOPARC', ':INSCRICAO'))
                ->andWhere(
                    $queryBuilder->expr()->or(
                        $queryBuilder->expr()->neq('PARC.NRPARCNEGOCIO', ':PKVALUE'),
                        $queryBuilder->expr()->isNull(':PKVALUE')
                    )
                )
                ->andWhere($queryBuilder->expr()->eq('PARC.NRORG', ':NRORG'));

            $queryBuilder->setParameter('CRM_NRORGTRAB', $paramsVerifyLeadCPNJ['CRM_NRORGTRAB']);
            $queryBuilder->setParameter('INSCRICAO', $paramsVerifyLeadCPNJ['INSCRICAO']);
            $queryBuilder->setParameter('PKVALUE', $paramsVerifyLeadCPNJ['PKVALUE']);
            $queryBuilder->setParameter('NRORG', $paramsVerifyLeadCPNJ['NRORG']);

            $leads = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $leads;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    // public function findSimilarLeads($paramsVerifyLeadName)
    // {
    //     try {
    //         $nrorg = $paramsVerifyLeadName['NRORG'];
    //         $nmpincipalparc = $paramsVerifyLeadName['NMCANDIDATO'];

    //         $queryBuilder = $this->connection->createQueryBuilder();
    //         $queryBuilder
    //             ->select(['PARC.NMPRINCIPALPARC'])
    //             ->from('PARCNEGOCIO', 'PARC')
    //             ->where('REGEXP_LIKE(UPPER(PARC.NMPRINCIPALPARC), :pattern)')
    //             ->andWhere('PARC.NRORG = :nrorg')
    //             ->setParameter('pattern', '.*' . strtoupper(preg_quote($nmpincipalparc)) . '.*')
    //             ->setParameter('nrorg', $nrorg);

    //         var_dump($queryBuilder->getSQL(), $queryBuilder->getParameters());
    //         die;
    //         $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
    //     } catch (\Exception $e) {
    // throw $e;
    //     }
    // }

    public function insertParcnegocio($params): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('PARCNEGOCIO')
                ->values([
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'NRORG' => ':NRORG',
                    'NMPRINCIPALPARC' => ':NMPRINCIPALPARC',
                    'NMSECUNDARIPARC' => ':NMSECUNDARIPARC',
                    'NRINSCRICAOPARC' => ':NRINSCRICAOPARC',
                    'IDATIVO' => ':IDATIVO',
                    'DTINCLUSAO' => 'SYSDATE',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                    'CDTIPOPARCPRINCIPAL' => ':CDTIPOPARCPRINCIPAL',
                    'CDTIPOINSCRICAO' => ':CDTIPOINSCRICAO',
                    'IDPESSOAFISICA' => ':IDPESSOAFISICA'
                ]);

            $queryBuilder->setParameter('NRPARCNEGOCIO', $params['NRPARCNEGOCIO']);
            $queryBuilder->setParameter('NRORG', $params['NRORG']);
            $queryBuilder->setParameter('NMPRINCIPALPARC', $params['NMPRINCIPALPARC']);
            $queryBuilder->setParameter('NMSECUNDARIPARC', $params['NMSECUNDARIPARC']);
            $queryBuilder->setParameter('NRINSCRICAOPARC', $params['NRINSCRICAOPARC']);
            $queryBuilder->setParameter('IDATIVO', $params['IDATIVO']);
            $queryBuilder->setParameter('NRORGINCLUSAO', $params['NRORGINCLUSAO']);
            $queryBuilder->setParameter('CDOPERINCLUSAO', $params['CDOPERINCLUSAO']);
            $queryBuilder->setParameter('CDTIPOPARCPRINCIPAL', $params['CDTIPOPARCPRINCIPAL']);
            $queryBuilder->setParameter('CDTIPOINSCRICAO', $params['CDTIPOINSCRICAO']);
            $queryBuilder->setParameter('IDPESSOAFISICA', $params['IDPESSOAFISICA']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertStatusParc($params): void
    {
        try {

            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('CRM_STATUSPARC')
                ->values([
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'NRPARCRESP' => ':NRPARCRESP',
                    'CDOPERRESP' => ':CDOPERRESP',
                    'STATUSPARC' => ':STATUSPARC',
                    'NRORG' => ':NRORG',
                    'CRM_NRORGTRAB' => ':CRM_NRORGTRAB',
                    'IDATIVO' => ':IDATIVO',
                    'DTINCLUSAO' => 'SYSDATE',
                    'DTULTATU' => 'SYSDATE',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                    'NRORGULTATU' => ':NRORGULTATU',
                    'CDOPERULTATU' => ':CDOPERULTATU',
                    'IDSTATUS' => ':IDSTATUS'
                ]);

            $queryBuilder->setParameter('NRPARCNEGOCIO', $params['NRPARCNEGOCIO']);
            $queryBuilder->setParameter('NRPARCRESP', $params['NRPARCRESP']);
            $queryBuilder->setParameter('CDOPERRESP', $params['CDOPERRESP']);
            $queryBuilder->setParameter('STATUSPARC', $params['STATUSPARC']);
            $queryBuilder->setParameter('NRORG', $params['NRORG']);
            $queryBuilder->setParameter('CRM_NRORGTRAB', $params['CRM_NRORGTRAB']);
            $queryBuilder->setParameter('IDATIVO', $params['IDATIVO']);
            $queryBuilder->setParameter('NRORGINCLUSAO', $params['NRORGINCLUSAO']);
            $queryBuilder->setParameter('CDOPERINCLUSAO', $params['CDOPERINCLUSAO']);
            $queryBuilder->setParameter('NRORGULTATU', $params['NRORGULTATU']);
            $queryBuilder->setParameter('CDOPERULTATU', $params['CDOPERULTATU']);
            $queryBuilder->setParameter('IDSTATUS', $params['IDSTATUS']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function verifyFilialOper($params)
    {
        if (!empty($params['CDOPERADOR'])) {
            try {
                $queryBuilder = $this->connection->createQueryBuilder();
                $queryBuilder
                    ->select([
                        'CDFILIAL',
                        'NRORG'
                    ])
                    ->from('FILIOPER')
                    ->where($queryBuilder->expr()->eq('CDOPERADOR', ':CDOPERADOR'))
                    ->andWhere($queryBuilder->expr()->eq('NRORG', ':NRORG'));

                $queryBuilder->setParameter('CDOPERADOR', $params['CDOPERADOR']);
                $queryBuilder->setParameter('NRORG', $params['NRORG']);

                $filial = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
                return $filial;
            } catch (\Exception $e) {
                throw $e;
            }
        } else {
            return array();
        }
    }

    public function insertnewContato($params): void
    {
        try {

            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('CONTATO')
                ->values([
                    'CDPROSPECT' => ':CDPROSPECT',
                    'CDCLIENTE' => ':CDCLIENTE',
                    'CDFORNECED' => ':CDFORNECED',
                    'DSREFECONT' => ':DSREFECONT',
                    'IDSTATUSCONT' => ':IDSTATUSCONT',
                    'IDTPCONTATO' => ':IDTPCONTATO',
                    'CDOPERCONT' => ':CDOPERCONT',
                    'NRORG' => ':NRORG',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'IDATIVO' => ':IDATIVO',
                    'CDFILIAL' => ':CDFILIAL',
                    'NRCONTATO' => ':NRCONTATO',
                    'NRSEQCONTATO' => ':NRSEQCONTATO',
                    'DTHRCONTATO' => 'SYSDATE',
                    'DTINCLUSAO' => 'SYSDATE',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                ])
                ->setParameters([
                    'DSREFECONT' => $params['DSREFECONT'],
                    'CDPROSPECT' => $params['CDPROSPECT'],
                    'CDCLIENTE' => $params['CDCLIENTE'],
                    'CDFORNECED' => $params['CDFORNECED'],
                    'IDSTATUSCONT' => $params['IDSTATUSCONT'],
                    'IDTPCONTATO' => $params['IDTPCONTATO'],
                    'CDOPERCONT' => $params['CDOPERCONT'],
                    'NRORG' => $params['NRORG'],
                    'NRPARCNEGOCIO' => $params['NRPARCNEGOCIO'],
                    'IDATIVO' => $params['IDATIVO'],
                    'CDFILIAL' => $params['CDFILIAL'],
                    'NRCONTATO' => $params['NRCONTATO'],
                    'NRSEQCONTATO' => $params['NRSEQCONTATO'],
                    'NRORGINCLUSAO' => $params['NRORG'],
                    'CDOPERINCLUSAO' => $params['CDOPERCONT'],
                ]);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getInfoContato($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'PROS.CDPROSPECT',
                    'CLIE.CDCLIENTE',
                    'FORN.CDFORNECED',
                ])
                ->from('PARCNEGOCIO', 'PARC')
                ->leftJoin('PARC', 'PROSPECT', 'PROS', 'PARC.NRPARCNEGOCIO = PROS.NRPARCNEGOCIO AND PARC.IDATIVO = PROS.IDATIVO AND PARC.NRORG = PROS.NRORG')
                ->leftJoin('PARC', 'CLIENTE', 'CLIE', 'PARC.NRPARCNEGOCIO = CLIE.NRPARCNEGOCIO AND PARC.IDATIVO = CLIE.IDATIVO AND PARC.NRORG = CLIE.NRORG')
                ->leftJoin('PARC', 'FORNECEDOR', 'FORN', 'PARC.NRPARCNEGOCIO = FORN.NRPARCNEGOCIO AND PARC.IDATIVO = FORN.IDATIVO AND PARC.NRORG = FORN.NRORG')
                ->where($queryBuilder->expr()->eq('PARC.NRPARCNEGOCIO', ':NRPARCNEGOCIO'))
                ->andWhere($queryBuilder->expr()->eq('PARC.NRORG', ':NRORG'))
                ->andWhere($queryBuilder->expr()->eq('PARC.IDATIVO', ':IDATIVO'))
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG'])
                ->setParameter('IDATIVO', 'S');

            $result = $queryBuilder->execute()->fetchAllAssociative();
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function createPartnership($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('PARCERIA')
                ->values([
                    'NRPARCERIA' => ':NRPARCERIA',
                    'NRORG' => ':NRORG',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'CDTIPOPARCEIRO' => ':CDTIPOPARCEIRO',
                    'IDATIVO' => ':IDATIVO',
                    'DTINCLUSAO' => 'SYSDATE',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                ])
                ->setParameters([
                    'NRPARCERIA' => $paramsQuery['NRPARCERIA'],
                    'NRORG' => $paramsQuery['NRORG'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'CDTIPOPARCEIRO' => $paramsQuery['CDTIPOPARCEIRO'],
                    'IDATIVO' => $paramsQuery['IDATIVO'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORGINCLUSAO'],
                ]);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }
    public function queryInsertParceria($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();

            $queryBuilder->insert(['PARCERIA'])
                ->values([
                    'NRPARCERIA' => ':NRPARCERIA',
                    'NRORG' => ':NRORG',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'CDTIPOPARCEIRO' => ':CDTIPOPARCEIRO',
                    'IDATIVO' => ':IDATIVO',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                ])
                ->setParameters([
                    'NRPARCERIA' => $paramsQuery['NRPARCERIA'],
                    'NRORG' => $paramsQuery['NRORG'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'CDTIPOPARCEIRO' => $paramsQuery['CDTIPOPARCEIRO'],
                    'IDATIVO' => $paramsQuery['IDATIVO'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORGINCLUSAO'],
                ]);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function setModoRecebInfo($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder->insert(['GER_PARCNEGOCIOINFO'])
                ->values([
                    'NRORG' => ':NRORG',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'NRMODORECEBINFO' => ':NRMODORECEBINFO'
                ])
                ->setParameters([
                    'NRORG' => $paramsQuery['NRORG'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'NRMODORECEBINFO' => $paramsQuery['NRMODORECEBINFO'],
                ]);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertNewInterlocutor($paramsQuery): void
    {
        try {

            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('CRM_INTERLOCUTOR')
                ->values([
                    'NRORG' => ':NRORG',
                    'IDATIVO' => ':IDATIVO',
                    'DTINCLUSAO' => 'SYSDATE',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'NMINTERLOCUTOR' => ':NMINTERLOCUTOR',
                    'NRSEQINTERLOCUTOR' => ':NRSEQINTERLOCUTOR',
                    'EMAILINTERLOC' => ':EMAILINTERLOC',
                    'NRTELEFONE1' => ':NRTELEFONE1',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                ])
                ->setParameters([
                    'NRORG' => $paramsQuery['NRORG'],
                    'IDATIVO' => $paramsQuery['IDATIVO'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'NMINTERLOCUTOR' => $paramsQuery['NMINTERLOCUTOR'],
                    'NRSEQINTERLOCUTOR' => $paramsQuery['NRSEQINTERLOCUTOR'],
                    'EMAILINTERLOC' => $paramsQuery['EMAILINTERLOC'],
                    'NRTELEFONE1' => $paramsQuery['NRTELEFONE1'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORG'],
                ]);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function mergePartner($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('CRM_FUSAO_PARC')
                ->values([
                    'NRSEQFUSAO' => ':NRSEQFUSAO',
                    'CDOPERDESFUSAO' => ':CDOPERDESFUSAO',
                    'DTDESFUSAO' => 'SYSDATE',
                    'NRPARCORI' => ':ORIGEM',
                    'NRPARCDEST' => ':DESTINO',
                    'NRORG' => ':NRORG',
                    'DTINCLUSAO' => 'SYSDATE',
                    'DTULTATU' => 'SYSDATE',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                    'NRORGULTATU' => ':NRORGULTATU',
                    'CDOPERULTATU' => ':CDOPERULTATU',
                    'IDATIVO' => ':IDATIVO'
                ])
                ->setParameters([
                    'NRSEQFUSAO' => $paramsQuery['NRSEQFUSAO'],
                    'CDOPERDESFUSAO' => $paramsQuery['CDOPERDESFUSAO'],
                    'ORIGEM' => $paramsQuery['PARCORIGINAL'],
                    'DESTINO' => $paramsQuery['NRPARCNEGOCIO'],
                    'NRORG' => $paramsQuery['NRORG'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORG'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERDESFUSAO'],
                    'NRORGULTATU' => $paramsQuery['NRORG'],
                    'CDOPERULTATU' => $paramsQuery['CDOPERDESFUSAO'],
                    'IDATIVO' => $paramsQuery['IDATIVO']
                ]);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getNrMaxMergeSeq($NRORG)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'MAX(NRSEQFUSAO) + 1 AS NRSEQFUSAO'
                ])
                ->from('CRM_FUSAO_PARC')
                ->where($queryBuilder->expr()->eq('NRORG', ':NRORG'))
                ->setParameter('NRORG', $NRORG);

            $result = $queryBuilder->execute()->fetchAllAssociative();
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateParcNegocio($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('PARCNEGOCIO')
                ->set('IDPARCFUNDIDO', $queryBuilder->expr()->literal('S'))
                ->set('IDATIVO', $queryBuilder->expr()->literal('N'))
                ->set('CDOPERULTATU', ':CDOPERADOR')
                ->set('DTULTATU', 'SYSDATE')
                ->where('NRPARCNEGOCIO = :PARCORIGINAL')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('CDOPERADOR', $paramsQuery['CDOPERADOR'])
                ->setParameter('PARCORIGINAL', $paramsQuery['PARCORIGINAL'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateContato($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('CONTATO')
                ->set('NRPARCNEGOCIO', ':NRPARCNEGOCIO')
                ->set('CDOPERULTATU', ':CDOPERADOR')
                ->set('DTULTATU', 'SYSDATE')
                ->set('NRORGULTATU', ':NRORG')
                ->where('NRORG = :NRORG')
                ->andWhere('NRPARCNEGOCIO = :PARCORIGINAL')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDOPERADOR', $paramsQuery['CDOPERADOR'])
                ->setParameter('PARCORIGINAL', $paramsQuery['PARCORIGINAL'])
                ->setParameter('NRORGULTATU', $paramsQuery['NRORG'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateOpportunity($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('CRM_OPORTUNI')
                ->set('NRPARCOPORT', ':NRPARCNEGOCIO')
                ->set('CDOPERULTATU', ':CDOPERADOR')
                ->set('DTULTATU', 'SYSDATE')
                ->set('NRORGULTATU', ':NRORG')
                ->where('NRORG = :NRORG')
                ->andWhere('NRPARCOPORT = :PARCORIGINAL')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDOPERADOR', $paramsQuery['CDOPERADOR'])
                ->setParameter('PARCORIGINAL', $paramsQuery['PARCORIGINAL'])
                ->setParameter('NRORGULTATU', $paramsQuery['NRORG'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateFilaContato($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('FILACONTATO')
                ->set('NRPARCNEGOCIO', ':NRPARCNEGOCIO')
                ->set('CDOPERULTATU', ':CDOPERADOR')
                ->set('DTULTATU', 'SYSDATE')
                ->set('NRORGULTATU', ':NRORG')
                ->where('NRORG = :NRORG')
                ->andWhere('NRPARCNEGOCIO = :PARCORIGINAL')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDOPERADOR', $paramsQuery['CDOPERADOR'])
                ->setParameter('PARCORIGINAL', $paramsQuery['PARCORIGINAL'])
                ->setParameter('NRORGULTATU', $paramsQuery['NRORG'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updatePlanoOcupacao($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('PLANOOCUPACAO')
                ->set('NRPARCNEGOCIO', ':NRPARCNEGOCIO')
                ->set('CDOPERULTATU', ':CDOPERADOR')
                ->set('DTULTATU', 'SYSDATE')
                ->set('NRORGULTATU', ':NRORG')
                ->where('NRORG = :NRORG')
                ->andWhere('NRPARCNEGOCIO = :PARCORIGINAL')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDOPERADOR', $paramsQuery['CDOPERADOR'])
                ->setParameter('PARCORIGINAL', $paramsQuery['PARCORIGINAL'])
                ->setParameter('NRORGULTATU', $paramsQuery['NRORG'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deactivateParcStatus($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->delete('CRM_STATUSPARC')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->andWhere('CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG'])
                ->setParameter('CRM_NRORGTRAB', $paramsQuery['CRM_NRORGTRAB']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function checkReceiveModeInfo($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'NRPARCNEGOCIO'
                ])
                ->from('GER_PARCNEGOCIOINFO')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $result = $queryBuilder->execute()->fetchAllAssociative();
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateModoRecebInfo($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('GER_PARCNEGOCIOINFO')
                ->set('NRMODORECEBINFO', ':NRMODORECEBINFO')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('NRMODORECEBINFO', $paramsQuery['NRMODORECEBINFO'])
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getComunicaparc($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'CDCOMUNICAPARC'
                ])
                ->from('COMUNICAPARC')
                ->where('CDCOMUNICAPARC = :CDCOMUNICAPARC')
                ->andWhere('CDFORMACOMU = :CDFORMACOMU')
                ->andWhere('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('CDCOMUNICAPARC', $paramsQuery['CDCOMUNICAPARC'])
                ->setParameter('CDFORMACOMU', $paramsQuery['CDFORMACOMU'])
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $result = $queryBuilder->execute()->fetchAllAssociative();
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertComunicaparc($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('COMUNICAPARC')
                ->values([
                    'CDCOMUNICAPARC' => ':CDCOMUNICAPARC',
                    'IDATIVO' => ':IDATIVO',
                    'DTINCLUSAO' => 'SYSDATE',
                    'NRCOMUNICAPARC' => ':NRCOMUNICAPARC',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'CDFORMACOMU' => ':CDFORMACOMU',
                    'NRORG' => ':NRORG',
                    'NRORGINCLUSAO' => $paramsQuery['NRORG'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                ])
                ->setParameters([
                    'CDCOMUNICAPARC' => $paramsQuery['CDCOMUNICAPARC'],
                    'IDATIVO' => $paramsQuery['IDATIVO'],
                    'NRCOMUNICAPARC' => $paramsQuery['NRCOMUNICAPARC'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'CDFORMACOMU' => $paramsQuery['CDFORMACOMU'],
                    'NRORG' => $paramsQuery['NRORG'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORG'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                ]);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getPhonePrinc($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'CDCOMUNICAPARC'
                ])
                ->from('COMUNICAPARC')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('CDFORMACOMU = :CDFORMACOMU')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDFORMACOMU', $paramsQuery['CDFORMACOMU'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $result = $queryBuilder->execute()->fetchAllAssociative();
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateMainPhone($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('COMUNICAPARC')
                ->set('CDCOMUNICAPARC', ':CDCOMUNICAPARC')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('CDFORMACOMU = :CDFORMACOMU')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('CDCOMUNICAPARC', $paramsQuery['CDCOMUNICAPARC'])
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDFORMACOMU', $paramsQuery['CDFORMACOMU'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveDtnascifundparc($paramsQuery)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('PARCNEGOCIO')
                ->set('DTNASCIFUNDPARC', ':DTNASCIFUNDPARC')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('DTNASCIFUNDPARC', $paramsQuery['DTNASCIFUNDPARC'])
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getAddressParc($nrParcNegocio, $nrOrg, $adressType = 'PRINCIPAL'): array
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    'NRENDERECOPARC'
                ])
                ->from('ENDERECOPARC')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('CDTIPOENDERECO = :CDTIPOENDERECO')
                ->andWhere('NRORG = :NRORG')
                ->setParameter('NRPARCNEGOCIO', $nrParcNegocio)
                ->setParameter('CDTIPOENDERECO', $adressType)
                ->setParameter('NRORG', $nrOrg);

            $result = $queryBuilder->execute()->fetchAllAssociative();
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertAddressParc($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('ENDERECOPARC')
                ->values([
                    'NRENDERECOPARC' => ':NRENDERECOPARC',
                    'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                    'CDTIPOENDERECO' => ':CDTIPOENDERECO',
                    'NRORG' => ':NRORG',
                    'IDATIVO' => ':IDATIVO',
                    'CDPAIS' => ':CDPAIS',
                    'SGESTADO' => ':SGESTADO',
                    'CDMUNICIPIO' => ':CDMUNICIPIO',
                    'CDBAIRRO' => ':CDBAIRRO',
                    'NRCEPENDERECO' => ':NRCEPENDERECO',
                    'DSENDERECO' => ':DSENDERECO',
                    'NRIMOVELENDERECO' => ':NRIMOVELENDERECO',
                    'DSCOMPLEENDERECO' => ':DSCOMPLEENDERECO',
                    'DTINCLUSAO' => 'SYSDATE',
                    'DTINCLUSAO' => 'SYSDATE',
                    'NRORGINCLUSAO' => ':NRORGINCLUSAO',
                    'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                ])
                ->setParameters([
                    'NRENDERECOPARC' => $paramsQuery['NRENDERECOPARC'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'CDTIPOENDERECO' => $paramsQuery['CDTIPOENDERECO'],
                    'NRORG' => $paramsQuery['NRORG'],
                    'IDATIVO' => $paramsQuery['IDATIVO'],
                    'CDPAIS' => $paramsQuery['CDPAIS'],
                    'SGESTADO' => $paramsQuery['SGESTADO'],
                    'CDMUNICIPIO' => $paramsQuery['CDMUNICIPIO'],
                    'CDBAIRRO' => $paramsQuery['CDBAIRRO'],
                    'NRCEPENDERECO' => $paramsQuery['NRCEPENDERECO'],
                    'DSENDERECO' => $paramsQuery['DSENDERECO'],
                    'NRIMOVELENDERECO' => $paramsQuery['NRIMOVELENDERECO'],
                    'DSCOMPLEENDERECO' => $paramsQuery['DSCOMPLEENDERECO'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORG'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                ]);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateAddressParc($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('ENDERECOPARC')
                ->set('CDPAIS', ':CDPAIS')
                ->set('SGESTADO', ':SGESTADO')
                ->set('CDMUNICIPIO', ':CDMUNICIPIO')
                ->set('CDBAIRRO', ':CDBAIRRO')
                ->set('NRCEPENDERECO', ':NRCEPENDERECO')
                ->set('DSENDERECO', ':DSENDERECO')
                ->set('NRIMOVELENDERECO', ':NRIMOVELENDERECO')
                ->set('DSCOMPLEENDERECO', ':DSCOMPLEENDERECO')
                ->set('CDOPERULTATU', ':CDOPERULTATU')
                ->set('DTULTATU', 'SYSDATE')
                ->set('NRORGULTATU', ':NRORG')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('CDTIPOENDERECO = :CDTIPOENDERECO')
                ->setParameter('NRENDERECOPARC', $paramsQuery['NRENDERECOPARC'])
                ->andWhere('NRORG = :NRORG')
                ->setParameter('CDPAIS', $paramsQuery['CDPAIS'])
                ->setParameter('SGESTADO', $paramsQuery['SGESTADO'])
                ->setParameter('CDMUNICIPIO', $paramsQuery['CDMUNICIPIO'])
                ->setParameter('CDBAIRRO', $paramsQuery['CDBAIRRO'])
                ->setParameter('NRCEPENDERECO', $paramsQuery['NRCEPENDERECO'])
                ->setParameter('DSENDERECO', $paramsQuery['DSENDERECO'])
                ->setParameter('NRIMOVELENDERECO', $paramsQuery['NRIMOVELENDERECO'])
                ->setParameter('DSCOMPLEENDERECO', $paramsQuery['DSCOMPLEENDERECO'])
                ->setParameter('CDOPERULTATU', $paramsQuery['CDOPERULTATU'])
                ->setParameter('NRORG', $paramsQuery['NRORG'])
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('CDTIPOENDERECO', $paramsQuery['CDTIPOENDERECO']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateResponsavel($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('CRM_STATUSPARC')
                ->set('NRPARCRESP', ':NRPARCRESP')
                ->set('CDOPERRESP', ':CDOPERRESP')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->andWhere('CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->setParameter('NRPARCRESP', $paramsQuery['NRPARCRESP'])
                ->setParameter('CDOPERRESP', $paramsQuery['CDOPERRESP'])
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG'])
                ->setParameter('CRM_NRORGTRAB', $paramsQuery['CRM_NRORGTRAB']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveLead($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->insert('CRM_CANDIDATO')
                ->values(
                    [
                        'NRCANDIDATO' => ':NRCANDIDATO',
                        "DESCTITULOCAN" => ':DESCTITULOCAN',
                        'IDTPIJURCAN' => ':IDTPIJURCAN',
                        'NRINSJURCAN' => ':NRINSJURCAN',
                        'NMCANDIDATO' => ':NMCANDIDATO',
                        'NMFANTCAN' => ':NMFANTCAN',
                        'DSEMAILCAN' => ':DSEMAILCAN',
                        'DSTELEFONECAN' => ':DSTELEFONECAN',
                        'IDSTATUSCAN' => ':IDSTATUSCAN',
                        'CDSEGMER' => ':CDSEGMER',
                        'NRFUNCCAN' => ':NRFUNCCAN',
                        'CDMODODIVULG' => ':CDMODODIVULG',
                        'CDPAIS' => ':CDPAIS',
                        'SGESTADO' => ':SGESTADO',
                        'CDMUNICIPIO' => ':CDMUNICIPIO',
                        'CDBAIRRO' => ':CDBAIRRO',
                        'NMBAIRROCAN' => ':NMBAIRROCAN',
                        'NRPARCPROPRI' => ':NRPARCPROPRI',
                        'NRPARCNEGOCIO' => ':NRPARCNEGOCIO',
                        'CDFILIAL' => ':CDFILIAL',
                        'NRCONTATO' => ':NRCONTATO',
                        'NRORG' => ':NRORG',
                        'IDATIVO' => ':IDATIVO',
                        'DTINCLUSAO' => 'SYSDATE',
                        'DTULTATU' => 'SYSDATE',
                        'NRORGINCLUSAO' => ':NRORG',
                        'CDOPERINCLUSAO' => ':CDOPERINCLUSAO',
                        'NRORGULTATU' => ':NRORG',
                        'CDOPERULTATU' => ':CDOPERULTATU',
                        'IDPARCFUNDIDO' => ':IDPARCFUNDIDO',
                        'NRSEQCONTATO' => ':NRSEQCONTATO',
                        'DSOBSERVACAOLEAD' => ':DSOBSERVACAOLEAD',
                        'NRIMOVELENDERECO' => ':NRIMOVELENDERECO',
                        'NRSEQPERFILRESPONSAVEL' => ':NRSEQPERFILRESPONSAVEL',
                    ]
                )
                ->setParameters([
                    'NRCANDIDATO' => $paramsQuery['NRCANDIDATO'],
                    'DESCTITULOCAN' => $paramsQuery['DESCTITULOCAN'],
                    'IDTPIJURCAN' => $paramsQuery['IDTPIJURCAN'],
                    'NRINSJURCAN' => $paramsQuery['NRINSJURCAN'],
                    'NMCANDIDATO' => $paramsQuery['NMCANDIDATO'],
                    'NMFANTCAN' => $paramsQuery['NMFANTCAN'],
                    'DSEMAILCAN' => $paramsQuery['DSEMAILCAN'],
                    'DSTELEFONECAN' => $paramsQuery['DSTELEFONECAN'],
                    'IDSTATUSCAN' => $paramsQuery['IDSTATUSCAN'],
                    'CDSEGMER' => $paramsQuery['CDSEGMER'],
                    'NRFUNCCAN' => $paramsQuery['NRFUNCCAN'],
                    'CDMODODIVULG' => $paramsQuery['CDMODODIVULG'],
                    'CDPAIS' => $paramsQuery['CDPAIS'],
                    'SGESTADO' => $paramsQuery['SGESTADO'],
                    'CDMUNICIPIO' => $paramsQuery['CDMUNICIPIO'],
                    'CDBAIRRO' => $paramsQuery['CDBAIRRO'],
                    'NMBAIRROCAN' => $paramsQuery['NMBAIRROCAN'],
                    'NRPARCPROPRI' => $paramsQuery['NRPARCPROPRI'],
                    'NRPARCNEGOCIO' => $paramsQuery['NRPARCNEGOCIO'],
                    'CDFILIAL' => $paramsQuery['CDFILIAL'],
                    'NRCONTATO' => $paramsQuery['NRCONTATO'],
                    'NRORG' => $paramsQuery['NRORG'],
                    'IDATIVO' => $paramsQuery['IDATIVO'],
                    'CDOPERINCLUSAO' => $paramsQuery['CDOPERINCLUSAO'],
                    'NRORGINCLUSAO' => $paramsQuery['NRORG'],
                    'NRORGULTATU' => $paramsQuery['NRORG'],
                    'CDOPERULTATU' => $paramsQuery['CDOPERULTATU'],
                    'IDPARCFUNDIDO' => $paramsQuery['IDPARCFUNDIDO'],
                    'NRSEQCONTATO' => $paramsQuery['NRSEQCONTATO'],
                    'DSOBSERVACAOLEAD' => $paramsQuery['DSOBSERVACAOLEAD'],
                    'NRIMOVELENDERECO' => $paramsQuery['NRIMOVELENDERECO'],
                    'NRSEQPERFILRESPONSAVEL' => $paramsQuery['NRSEQPERFILRESPONSAVEL'],
                    'PORTCANDIDATO' => $paramsQuery['PORTCANDIDATO'],
                    'QNTDUSUARIOS' => $paramsQuery['QNTDUSUARIOS'],
                    'QNTDUNIDADES' => $paramsQuery['QNTDUNIDADES'],
                    'QNTPONTOSACESSO' => $paramsQuery['QNTPONTOSACESSO'],
                    'FISCAL' => $paramsQuery['FISCAL'],
                    'CDMODATEND' => $paramsQuery['CDMODATEND'],
                    'NRREFEICOESDIA' => $paramsQuery['NRREFEICOESDIA']
                ]);
            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function qualifyLead($paramsQuery): void
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->update('CRM_STATUSPARC')
                ->set('IDSTATUS', ':IDSTATUSCAN')
                ->set('CDOPERULTATU', ':CDOPERULTATU')
                ->where('NRPARCNEGOCIO = :NRPARCNEGOCIO')
                ->andWhere('NRORG = :NRORG')
                ->andWhere('CRM_NRORGTRAB = :CRM_NRORGTRAB')
                ->setParameter('NRPARCNEGOCIO', $paramsQuery['NRPARCNEGOCIO'])
                ->setParameter('NRORG', $paramsQuery['NRORG'])
                ->setParameter('CRM_NRORGTRAB', $paramsQuery['CRM_NRORGTRAB'])
                ->setParameter('IDSTATUSCAN', $paramsQuery['IDSTATUSCAN'])
                ->setParameter('CDOPERULTATU', $paramsQuery['CDOPERULTATU']);

            $this->connection->executeStatement($queryBuilder->getSQL(), $queryBuilder->getParameters());
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
