<?php

namespace CRM\Service;

use CRM\Factory\CrmCargoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmCargoService
{

    protected $CargoFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmCargoFactory $CargoFactory)
    {
        $this->CargoFactory                 = $CargoFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getCrmCargo()
    {
        return $this->CargoFactory->getCrmCargo();
    }

    public function saveCrmCargo($rows)
    { 
       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();

        foreach ($rows["DRG"] as $row) {
            if ($row["CDCARGOINTERLOC"] == 0) {
                $this->checkExistingCargo($nrorg, $row);
                $novoCodigo = $this->newCode->getCodeByTableName("CARGOINTERLOC", $nrorg, 1, 5, false);

                    $params = array(
                    "CDCARGOINTERLOC"   => $novoCodigo,
                    "NMCARGOINTERLOC"   => $row["NMCARGOINTERLOC"],
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->CargoFactory->insertCrmCargo($params);
            } else {
                $this->checkExistingCargo($nrorg, $row);
                $params = array(
                    "CDCARGOINTERLOC"   => $row["CDCARGOINTERLOC"],
                    "NMCARGOINTERLOC"   => $row["NMCARGOINTERLOC"],
                    "NRORGULTATU"       => $nrorg,
                    "NRORG"             => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->CargoFactory->editCrmCargo($params);

            }
            }
            
             $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function checkExistingCargo ($nrorg, $row)
    {
        try {
            $params = array(
                "CDCARGOINTERLOC"   => $row["CDCARGOINTERLOC"],
                "NMCARGOINTERLOC"   => $row["NMCARGOINTERLOC"],
                "NRORG"             => $nrorg,
            );
            
            $existe =  $this->CargoFactory->checkExistingCargo($params);
            if ($existe > 0 ) {
                throw new \Exception("EXISTE");
            }
        } catch (\Exception $ex) {
            throw $ex;
        }
    }

    public function deleteCrmCargo ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "CDCARGOINTERLOC"   => $item["CDCARGOINTERLOC"],
                    "NRORG" => $nrorg,
                );

                $this->CargoFactory->deleteCrmCargo($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

}