<?php

namespace CRM\Service;

use CRM\Factory\CrmMetasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmMetasService
{

    protected $CrmMetasFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmMetasFactory $CrmMetasFactory)
    {
        $this->CrmMetasFactory         = $CrmMetasFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getCrmMetasService()
    {
        return $this->CrmMetasFactory->getCrmMetasFactory();
    }

    public function saveEditMeta($row){
        $this->connection->beginTransaction();
        try{
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();

            $dataparams = array(
                "NRMETAS"           => $row["NRMETAS"],
                "NMMETA"            => $row["NMMETA"],
                "CDTIPOMETA"        => $row["CDTIPOMETA"],
                "VRMINMETA"         => $row["VRMINMETA"],
                "NRORG"             => $nrorg,
                "NRORGULTATU"       => $nrorg,
                "CDOPERULTATU"      => $operador,
                "IDATIVO"           => $row["IDATIVO"]
            );
            $this->CrmMetasFactory->saveEditMeta($dataparams);
            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
}


    public function saveNewMeta($row)
    { 
       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();
        $novoCodigo = $this->newCode->getCodeByTableName("NRMETAS", $nrorg, 1, 5, false);

        $params = array(
            "NRMETAS"           => $novoCodigo,
            "NMMETA"            => $row["NMMETA"],
            "CDTIPOMETA"        => $row["CDTIPOMETA"],
            "VRMINMETA"         => $row["VRMINMETA"],
            "NRORG"             => $nrorg,
            "NRORGINCLUSAO"     => $nrorg,
            "CDOPERINCLUSAO"    => $operador,
            "NRORGULTATU"       => $nrorg,
            "CDOPERULTATU"      => $operador,
            "IDATIVO"           => $row["IDATIVO"]
        );
        $this->CrmMetasFactory->insertNewMeta($params);  
        $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function deleteMeta ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {
                

                $params = array(
                    "NRMETAS"   => $item["NRMETAS"],
                    "NRORG" => $nrorg,
                );

                $this->CargoFactory->deleteMeta($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function saveOperadorMeta($rows){
       
        $this->connection->beginTransaction();
        try{
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();
            foreach ($rows["OPERADOR"] as $row) {
                $novoCodigo = $this->newCode->getCodeByTableName("CRM_OPERMETA", $nrorg, 1, 5, false);
                $dataparams = array(
                    "NROPERMETA"        => $novoCodigo,
                    "NRMETAS"           => $rows["NRMETAS"],
                    "CDOPERADOR"        => $row["CDOPERADOR"],
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORG"             => $nrorg,
                );
                $this->CrmMetasFactory->insertOperadorMeta($dataparams);
               
            }
            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
}


    public function getOperadoresMeta($params)
    {
        $dataParams = array(
            "NRMETAS"   => $params["NRMETAS"],
            
        );
        return $this->CrmMetasFactory->getOperadoresMeta($dataParams);
    }

    
    public function getOperadorMeta($params)
    {
        $dataParams = array(
           
            "IDTPOPERADOR"   => "E",
            "CDTIPOMETA"     => $params["CDTIPOMETA"],
            "NRREVENDA"      => NULL,
           
        );
        return $this->CrmMetasFactory->getOperadorMeta($dataParams);
    }
 
    public function deleteCrmMetaOperador ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "NROPERMETA"        =>  $item["NROPERMETA"],
                    "NRMETAS"           =>  $item["NRMETAS"],
                    "NRORG"             => $nrorg,
                );

                $this->CrmMetasFactory->deleteCrmMetaOperador($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    public function deleteCrmMetaRegistro ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "NRMETAS"           =>  $item["NRMETAS"],
                    "NRORG"             => $nrorg,
                );

                $this->CrmMetasFactory->deleteCrmMetaRegistro($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

}
