import { Utilities } from '@/util/Utilities';
import {
  Button, Form, LoadingService, Modal, ModalService, Select, TextInput,
  Tabs,
  Footer,
  DialogService,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmMetasController {
  private modalAdicionarMeta!: Modal;

  private modalAdicionarOperadores!: Modal;

  private tekGridMetasVisible: boolean = true;

  private currentRow: any = {};

  get tituloFrame() {
    return this.currentRow.NMMETA;
  }

  get frameVisible() {
    return !this.tekGridMetasVisible;
  }

  public abrirFrame({ row }: any) {
    this.tekGridMetasVisible = false;
    this.currentRow = row;
    this.loadTabsCrmMetas();
  }

  public voltarGridMetas() {
    this.tekGridMetasVisible = true;
    this.ativaTabDescricao();
  }

  public ativaTabDescricao() {
    const setOfTabs = Metadata.getInstance<Tabs>('tabs-frame-CrmMetas');
    setOfTabs.activeTab = 0;
  }

  public async openModalNewOperadores() {
    this.modalAdicionarOperadores = await ModalService.createFromJson('crm_metas/Modal/modal_operadores_meta', true);
    await this.modalAdicionarOperadores.show();
  }

  public closeModalOperadores() {
    this.modalAdicionarOperadores.hide();
    this.modalAdicionarOperadores?.destroy();
  }

  public async openModalNewMeta() {
    this.modalAdicionarMeta = await ModalService.createFromJson('crm_metas/Modal/modal_new_meta', true);
    await this.modalAdicionarMeta.show();
  }

  public closeModal() {
    this.modalAdicionarMeta.hide();
    this.modalAdicionarMeta?.destroy();
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public carregarDadosMetas() {
    Metadata.getInstance<TextInput>('NRMETAS-DESCRICAO-META').value = this.currentRow.NRMETAS;
    Metadata.getInstance<TextInput>('NMMETA-DESCRICAO-META').value = this.currentRow.NMMETA;
    Metadata.getInstance<Select>('IDATIVO-DESCRICAO-META').value = this.currentRow.IDATIVO;
    Metadata.getInstance<Select>('CDTIPOMETA-DESCRICAO-META').value = this.currentRow.CDTIPOMETA;
    Metadata.getInstance<TextInput>('VRMINMETA-DESCRICAO-META').value = this.currentRow.VRMINMETA;
  }

  public saveNewMeta() {
    const formulario = Metadata.getInstance<Form>('form-adicionarMeta');
    const gridMeta = Metadata.getInstance<TekGrid>('tek-grid-crmMetas_grid');
    if (Utilities.validateForm(formulario)) {
      LoadingService.show();
      Http.post('/saveNewMeta', {
        NMMETA: Metadata.getInstance<TextInput>('NMMETA-MODAL-META').value,
        IDATIVO: Metadata.getInstance<Select>('IDATIVO-MODAL-META').value,
        CDTIPOMETA: Metadata.getInstance<Select>('CDTIPOMETA-MODAL-META').value,
        VRMINMETA: Metadata.getInstance<TextInput>('VRMINMETA-MODAL-META').value,
      }).then(() => {
        gridMeta.datasource.get();
        this.closeModal();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        LoadingService.hide();
      });
    } else {
      Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
    }
  }

  public saveEditMeta() {
    const formulario = Metadata.getInstance<Form>('form-descricaoMeta');
    const gridMeta = Metadata.getInstance<TekGrid>('tek-grid-crmMetas_grid');
    if (Utilities.validateForm(formulario)) {
      LoadingService.show();
      Http.post('/saveEditMeta', {
        NRMETAS: Metadata.getInstance<TextInput>('NRMETAS-DESCRICAO-META').value,
        NMMETA: Metadata.getInstance<TextInput>('NMMETA-DESCRICAO-META').value,
        IDATIVO: Metadata.getInstance<Select>('IDATIVO-DESCRICAO-META').selectValue.IDATIVO,
        CDTIPOMETA: Metadata.getInstance<Select>('CDTIPOMETA-DESCRICAO-META').selectValue.CDTIPOMETA,
        VRMINMETA: Metadata.getInstance<TextInput>('VRMINMETA-DESCRICAO-META').value,
      }).then(() => {
        gridMeta.datasource.get();
        this.voltarGridMetas();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }

  public saveOperadorMeta() {
    const formulario = Metadata.getInstance<Form>('form-descricaoMeta');
    const gridOperadores = Metadata.getInstance<TekGrid>('TekGrid-CrmMetasOperadores');
    if (Utilities.validateForm(formulario)) {
      LoadingService.show();
      const operador = Metadata.getInstance<Select>('modal-cadastro-operador-CDOPERADOR').selectValue;
      Http.post('/saveOperadorMeta', {
        OPERADOR: operador,
        NRMETAS: this.currentRow.NRMETAS,
      }).then(() => {
        gridOperadores.datasource.get();
        this.closeModalOperadores();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }

  public setFilterCampoOperador({ component }: any) {
    component.datasource.setFilter({
      CDTIPOMETA: this.currentRow.CDTIPOMETA,
    });
  }

  public loadTabsCrmMetas() {
    const setOfTabs = Metadata.getInstance<Tabs>('tabs-frame-CrmMetas');
    const footer = Metadata.getInstance<Footer>('footer-DESCRICAO-Meta');
    if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab-descricao-CrmMetas') {
      this.carregarDadosMetas();
      footer.isVisible = true;
    } else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab-operadores-CrmMetas') {
      this.setFilterOperadoresCrmMetas();
      footer.isVisible = false;
    }
  }

  public setFilterOperadoresCrmMetas() {
    try {
      const grid = Metadata.getInstance<TekGrid>('TekGrid-CrmMetasOperadores');
      grid.datasource.setFilter({
        NRMETAS: this.currentRow.NRMETAS,
      });
    } catch (e) {
      // console.error(e);
    }
  }

  public messageConfirmDelete({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmMetasController.deleteCrmMetaOperador');
  }

  public deleteCrmMetaOperador() {
    const grid = Metadata.getInstance<TekGrid>('TekGrid-CrmMetasOperadores');
    LoadingService.show();
    Http.post('/deleteCrmMetaOperador', {
      NRS: grid.selectedRows,
    }).then(() => {
      grid.selectedRows = [];
      grid.reload();
      Utilities.showSuccessMessage();
    }).catch((error) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }

  public messageConfirmDeleteMetaRegistro({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmMetasController.deleteCrmMetaRegistro');
  }

  public deleteCrmMetaRegistro() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-crmMetas_grid');
    LoadingService.show();
    Http.post('/deleteCrmMetaRegistro', {
      NRS: grid.selectedRows,
    }).then(() => {
      grid.selectedRows = [];
      grid.reload();
      Utilities.showSuccessMessage();
    }).catch((error) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
