import {
  IEventParam,
  Metadata,
  Http,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import {
  Button,
  LoadingService,
  DialogService,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class CrmModoDivulgacaoController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ CDMODODIVULG: newId, IDATIVO: 'S' }, 'start');
  }

  public saveNewDisclosureMode({ component, event }: IEventParam<TekGrid>) {
    event!.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveNewDisclosureMode', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public reloadGrid(grid: any) {
    const filterButton = Metadata.getInstance<Button>(`${grid}_refreshButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public openFilterDisclosureMode({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  /* eslint-disable */
  public canEditRow({ row }: any) {
    return row['__added_row'] === true;
  }
  /* eslint-enable */

  public dialogdeleteDisclosureMode({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmModoDivulgacaoController.deleteDisclosureMode');
  }

  public deleteDisclosureMode() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-crm_modo_de_divulgacao_grid');
    LoadingService.show();
    Http.post('/deleteDisclosureMode', {
      CDGS: (grid.selectedRows.map((element: any) => element.CDMODODIVULG)),
    }).then(() => {
      grid.datasource.get();
      Utilities.showSuccessMessage();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
